@@ -4,7 +4,7 @@
  * Gnome Crystal
  * document.h 
  *
- * Copyright (C) 2000-2006 Jean Brfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2000-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,10 +28,10 @@
 #include <libxml/parser.h>
 #include <gcu/crystaldoc.h>
 #include <gcu/dialog.h>
+#include <gcu/macros.h>
 #include "atom.h"
 #include "line.h"
 #include "cleavage.h"
-#include <libbonobo.h>
 
 using namespace gcu;
 
@@ -54,30 +54,25 @@ public:
 	void Update();
 	void UpdateAllViews();
 	void SetWidget(GtkWidget* widget){m_widget = widget;}
-	gdouble GetMaxDist() {return m_dDist;}
 	void GetSize(gdouble* xmin, gdouble* xmax, gdouble* ymin, gdouble* ymax, gdouble* zmin, gdouble* zmax);
 	void SetSize(gdouble xmin, gdouble xmax, gdouble ymin, gdouble ymax, gdouble zmin, gdouble zmax);
 	void GetCell(gcLattices *lattice, gdouble *a, gdouble *b, gdouble *c, gdouble *alpha, gdouble *beta, gdouble *gamma);
 	void SetCell(gcLattices lattice, gdouble a, gdouble b, gdouble c, gdouble alpha, gdouble beta, gdouble gamma);
 	const gchar* GetFileName() {return m_filename;}
-	void SetFileName(const gchar* filename);
+	void SetFileName(const string &filename);
 	gchar* GetTitle() {return m_title;}
 	void SetTitle(const gchar* title);
-	void Save();
-	bool Load(const gchar* filename);
+	void Save ();
+	bool Load (const string &filename);
+	bool Import (const string &filename, const string& mime_type);
 	void ParseXMLTree(xmlNode* xml);
 	void OnNewDocument();
-	void OnExportVRML(const gchar* FileName);
+	void OnExportVRML (const string &FileName);
 	gcView* GetNewView();
-	void SetDirty();
-	bool IsEmpty() {return m_bEmpty;}
 	void AddView(gcView* pView);
 	bool RemoveView(gcView* pView);
 	void RemoveAllViews ();
 	bool VerifySaved();
-	void SetBonoboPersist(BonoboPersist* ps) {m_ps = ps;}
-	void NotifyDialog(Dialog* dialog);
-	void RemoveDialog(Dialog* dialog);
 	bool GetFixedSize() {return m_bFixedSize;}
 	void SetFixedSize(bool FixedSize) {m_bFixedSize = FixedSize;}
 	virtual CrystalView* CreateNewView();
@@ -85,11 +80,12 @@ public:
 	virtual CrystalLine* CreateNewLine();
 	virtual CrystalCleavage* CreateNewCleavage();
 	virtual const char* GetProgramId();
-	gcApplication* GetApplication () {return m_App;}
 	void SetActiveView (gcView *pView) {m_pActiveView = pView;}
-	void SaveAsImage (char const *filename, char const *type, map<string, string>& options);
+	void SaveAsImage (const string &filename, char const *type, map<string, string>& options);
 	gcView *GetActiveView () {return m_pActiveView;}
 	virtual bool LoadNewView (xmlNodePtr node);
+	list <CrystalView *> *GetViews () {return &m_Views;}
+	void RenameViews ();
 
 private:
 	void Error(int num);
@@ -100,9 +96,9 @@ private:
 	bool m_bClosing;
 	GtkWidget* m_widget;
 	std::list <Dialog *> m_Dialogs;
-	BonoboPersist* m_ps;
-	gcApplication* m_App;
 	gcView *m_pActiveView;
+
+GCU_RO_PROP (bool, ReadOnly);
 };
 
 #endif //GCRYSTAL_DOCUMENT_H
